@@ -1,4 +1,4 @@
-ascii.table <- function (x, include.rownames = TRUE, include.colnames = TRUE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", ...){
+ascii.table <- function (x, include.rownames = TRUE, include.colnames = TRUE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = ".", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", ...){
 
   if (length(dim(x)) == 1 | is.null(dim(x))) {
     y <- as.data.frame(t(unclass(x)))
@@ -14,7 +14,7 @@ ascii.table <- function (x, include.rownames = TRUE, include.colnames = TRUE, fo
   obj <- ascii(x = y, include.rownames = include.rownames,
       include.colnames = include.colnames, format = format,
       digits = digits, decimal.mark = decimal.mark, na.print = na.print,
-      caption = caption, width = width, frame = frame, grid = grid,
+      caption = caption, caption.level = caption.level, width = width, frame = frame, grid = grid,
       valign = valign, header = header, footer = footer, align = align,
       col.width = col.width, style = style)
   class(obj) <- c("ascii", "proto", "environment")
