@@ -1,45 +1,45 @@
-ascii.integer <- function (x, include.rownames = FALSE, include.colnames = FALSE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", width = 0, frame = "", grid = "", valign = "", header = FALSE, footer = FALSE, align = "", col.width = 1, style = "", ...){
+ascii.integer <- function (x, include.rownames = FALSE, include.colnames = FALSE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = ".", width = 0, frame = "", grid = "", valign = "", header = FALSE, footer = FALSE, align = "", col.width = 1, style = "", ...){
     x <- as.data.frame(t(x))
     obj <- asciiDataFrame$new(x = x, include.rownames = include.rownames,
          include.colnames = include.colnames, format = format,
          digits = digits, decimal.mark = decimal.mark, na.print = na.print,
-         caption = caption, width = width, frame = frame, grid = grid,
+         caption = caption, caption.level = caption.level, width = width, frame = frame, grid = grid,
          valign = valign, header = header, footer = footer, align = align,
          col.width = col.width, style = style)
     class(obj) <- c("ascii", "proto", "environment")
     return(obj)
 }
 
-ascii.numeric <- function (x, include.rownames = FALSE, include.colnames = FALSE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", width = 0, frame = "", grid = "", valign = "", header = FALSE, footer = FALSE, align = "", col.width = 1, style = "", ...){
+ascii.numeric <- function (x, include.rownames = FALSE, include.colnames = FALSE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = ".", width = 0, frame = "", grid = "", valign = "", header = FALSE, footer = FALSE, align = "", col.width = 1, style = "", ...){
     x <- as.data.frame(t(x))
     obj <- asciiDataFrame$new(x = x, include.rownames = include.rownames,
          include.colnames = include.colnames, format = format,
          digits = digits, decimal.mark = decimal.mark, na.print = na.print,
-         caption = caption, width = width, frame = frame, grid = grid,
+         caption = caption, caption.level = caption.level, width = width, frame = frame, grid = grid,
          valign = valign, header = header, footer = footer, align = align,
          col.width = col.width, style = style)
     class(obj) <- c("ascii", "proto", "environment")
     return(obj)
 }
 
-ascii.character <- function (x, include.rownames = FALSE, include.colnames = FALSE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", width = 0, frame = "", grid = "", valign = "", header = FALSE, footer = FALSE, align = "", col.width = 1, style = "", ...){
+ascii.character <- function (x, include.rownames = FALSE, include.colnames = FALSE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = ".", width = 0, frame = "", grid = "", valign = "", header = FALSE, footer = FALSE, align = "", col.width = 1, style = "", ...){
     x <- as.data.frame(t(x))
     obj <- asciiDataFrame$new(x = x, include.rownames = include.rownames,
          include.colnames = include.colnames, format = format,
          digits = digits, decimal.mark = decimal.mark, na.print = na.print,
-         caption = caption, width = width, frame = frame, grid = grid,
+         caption = caption, caption.level = caption.level, width = width, frame = frame, grid = grid,
          valign = valign, header = header, footer = footer, align = align,
          col.width = col.width, style = style)
     class(obj) <- c("ascii", "proto", "environment")
     return(obj)
 }
 
-ascii.factor <- function (x, include.rownames = FALSE, include.colnames = FALSE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", width = 0, frame = "", grid = "", valign = "", header = FALSE, footer = FALSE, align = "", col.width = 1, style = "", ...){
+ascii.factor <- function (x, include.rownames = FALSE, include.colnames = FALSE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = ".", width = 0, frame = "", grid = "", valign = "", header = FALSE, footer = FALSE, align = "", col.width = 1, style = "", ...){
     x <- as.data.frame(t(as.character(x)))
     obj <- asciiDataFrame$new(x = x, include.rownames = include.rownames,
          include.colnames = include.colnames, format = format,
          digits = digits, decimal.mark = decimal.mark, na.print = na.print,
-         caption = caption, width = width, frame = frame, grid = grid,
+         caption = caption, caption.level = caption.level, width = width, frame = frame, grid = grid,
          valign = valign, header = header, footer = footer, align = align,
          col.width = col.width, style = style)
     class(obj) <- c("ascii", "proto", "environment")
